w, h = love.graphics.getDimensions!
cellSize = 5

-- Rainfall: Dry -> Wet (desert -> rainforest)
--  Variation (seasonality)
-- Altitude: Low -> High (deep ocean -> mountains)
--  Variation (flat -> craggy)
-- Temperature: Freezing -> Boiling (arctic -> desert)
--  Variation (seasonality)
-- Soil: Soft -> Hard (fertile soil -> hard rock)
--  Variation (seasonality, would only apply for soil?)

colors = {
  desert: { 255/255, 210/255, 33/255, 1 }
  ocean: { 73/255, 132/255, 252/255, 1 }
  mountains: { 140/255, 58/255, 0, 1 }
  "tropical rainforest": { 8/255, 71/255, 0, 1}
  tundra: { 196/255, 0, 26/255, 1 }
  taiga: { 175/255, 45/255, 63/255, 1 }
  grassland: { 38/255, 160/255, 1/255, 1 }
  savanna: { 183/255, 141/255, 14/255, 1 }
}

biomes = {
  desert: { precipitation: { 0, 0.2 } }
  ocean: { altitude: { 0, 1/3 } }
  mountains: { altitude: { 0.8, 1 } }
  "tropical rainforest": { precipitation: { 0.8, 1 }, temperature: { 0.8, 1, variation: { 0, 0.2 } } }
  tundra: { altitude: { 0, 1, variation: { 0, 0.1 } }, temperature: { 0, 1/3 } }
  taiga: { temperature: { 0.1, 1/3, variation: { 0, 1/3 } }, precipitation: { 0.2, 0.5 } }
  grassland: { precipitation: { 0.2, 1/3 } }
  savanna: { precipitation: { 1/3, 0.42 } }
}

-- Temperate Forest: four distinct seasons (fall, winter, spring, summer)
--   Freshwater: lakes, streams, rivers
--   Marine: salt-water oceans

map = {}
map.set = (x, y, v) ->
  map[x] = {} unless map[x]
  map[x][y] = v
map.get = (x, y) ->
  if map[x]
    return map[x][y] or { 0, 0, 0, 1 }
  else
    return { 0, 0, 0, 1 }

love.load = ->
  for x = 1, w / cellSize
    for y = 1, h / cellSize
      r = love.math.noise x / 10, y / 10
      map.set x, y, { r, r, r, 1 }

love.draw = ->
  for x = 1, w / cellSize
    for y = 1, h / cellSize
      love.graphics.setColor map.get x, y
      love.graphics.rectangle "fill", (x - 1) * cellSize, (y - 1) * cellSize, cellSize, cellSize

  love.graphics.setColor 0, 0, 0, 1/3
  love.graphics.rectangle "fill", 0, 0, w, 16
  love.graphics.setColor 1, 1, 1, 1
  love.graphics.print love.timer.getFPS!

love.keypressed = (key) -> love.event.quit!
